Skip to contents

Creates a collection from an existing index. Collections are static copies of an index that can be used to create new indexes.

Usage

create_collection(name, source)

Arguments

name

Name for the new collection

source

Name of the source index to create the collection from

Value

List with http response, content, and status_code - 201: The collection has been successfully created - 400: Bad request (quota exceeded or invalid name) - 409: A collection with this name already exists - 500: Internal error

Examples

if (FALSE) { # \dontrun{
create_collection("my-collection", source = "my-index")
} # }