Extracts the full host from an index description for data plane operations.
Examples
if (FALSE) { # \dontrun{
index <- describe_index("my-index")
host <- get_index_host(index)
} # }
Extracts the full host from an index description for data plane operations.
if (FALSE) { # \dontrun{
index <- describe_index("my-index")
host <- get_index_host(index)
} # }