Skip to contents

Lists all recent and ongoing import operations for an index.

Usage

list_imports(index, limit = 100, pagination_token = NULL)

Arguments

index

Name of the index

limit

Maximum number of operations to return (default: 100)

pagination_token

Token for fetching the next page of results

Value

List with http response, content (import operations), and status_code. Content includes: - data: list of import operations with id, status, uri, etc. - pagination: list with next token if more results exist

Examples