Constructs URLs for Pinecone's Assistant data plane API.
This is used for file operations and chat operations.
The data plane host is typically returned when creating/describing an assistant.
Usage
get_assistant_data_url(host, set_path = NA)
Arguments
- host
The assistant data plane host (e.g., "prod-1-data.ke.pinecone.io")
- set_path
API path (e.g., "assistant/files/my-assistant", "assistant/chat/my-assistant")
Value
Full URL string for the assistant data plane API
Examples
if (FALSE) { # \dontrun{
get_assistant_data_url("prod-1-data.ke.pinecone.io", "assistant/files/my-assistant")
get_assistant_data_url("prod-1-data.ke.pinecone.io", "assistant/chat/my-assistant")
} # }